@@ -13,31 +13,29 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
+import logging
 import os
 
 import glance_store as store_api
 from glance_store import backend
-from oslo_concurrency import processutils as putils
 from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_utils import encodeutils
-from oslo_utils import excutils
 import six
 from stevedore import named
 from taskflow.patterns import linear_flow as lf
 from taskflow import retry
 from taskflow import task
-from taskflow.types import failure
 
-from glance.async import utils
 from glance.common import exception
 from glance.common.scripts.image_import import main as image_import
 from glance.common.scripts import utils as script_utils
-from glance.i18n import _, _LE, _LI
+from glance.common import utils as common_utils
+from glance import i18n
 
 
 LOG = logging.getLogger(__name__)
+_ = i18n._
+_LE = i18n._LE
+_LI = i18n._LI
 
 
 CONF = cfg.CONF
@@ -66,21 +64,18 @@ class _CreateImage(task.Task):
             self.image_repo, self.image_factory,
             task_input.get('image_properties'), self.task_id)
 
-        LOG.debug("Task %(task_id)s created image %(image_id)s",
+        LOG.debug("Task %(task_id)s created image %(image_id)s" %
                   {'task_id': task.task_id, 'image_id': image.image_id})
         return image.image_id
 
     def revert(self, *args, **kwargs):
-        # TODO(NiallBunting): Deleting the image like this could be considered
-        # a brute force way of reverting images. It may be worth checking if
-        # data has been written.
-        result = kwargs.get('result', None)
-        if result is not None:
-            if kwargs.get('flow_failures', None) is not None:
-                image = self.image_repo.get(result)
-                LOG.debug("Deleting image whilst reverting.")
-                image.delete()
-                self.image_repo.remove(image)
+        # TODO(flaper87): Define the revert rules for images on failures.
+        # Deleting the image may not be what we want since users could upload
+        # the image data in a separate step. However, it really depends on
+        # when the failure happened. I guess we should check if data has been
+        # written, although at that point failures are (should be) unexpected,
+        # at least image-workflow wise.
+        pass
 
 
 class _ImportToFS(task.Task):
@@ -151,37 +146,13 @@ class _ImportToFS(task.Task):
         data = script_utils.get_image_data_iter(self.uri)
 
         path = self.store.add(image_id, data, 0, context=None)[0]
-
-        try:
-            # NOTE(flaper87): Consider moving this code to a common
-            # place that other tasks can consume as well.
-            stdout, stderr = putils.trycmd('qemu-img', 'info',
-                                           '--output=json', path,
-                                           prlimit=utils.QEMU_IMG_PROC_LIMITS,
-                                           log_errors=putils.LOG_ALL_ERRORS)
-        except OSError as exc:
-            with excutils.save_and_reraise_exception():
-                exc_message = encodeutils.exception_to_unicode(exc)
-                msg = _LE('Failed to execute security checks on the image '
-                          '%(task_id)s: %(exc)s')
-                LOG.error(msg, {'task_id': self.task_id, 'exc': exc_message})
-
-        metadata = json.loads(stdout)
-
-        backing_file = metadata.get('backing-filename')
-        if backing_file is not None:
-            msg = _("File %(path)s has invalid backing file "
-                    "%(bfile)s, aborting.") % {'path': path,
-                                               'bfile': backing_file}
-            raise RuntimeError(msg)
-
         return path
 
-    def revert(self, image_id, result, **kwargs):
-        if isinstance(result, failure.Failure):
-            LOG.exception(_LE('Task: %(task_id)s failed to import image '
-                              '%(image_id)s to the filesystem.'),
-                          {'task_id': self.task_id, 'image_id': image_id})
+    def revert(self, image_id, result=None, **kwargs):
+        # NOTE(flaper87): If result is None, it probably
+        # means this task failed. Otherwise, we would have
+        # a result from its execution.
+        if result is None:
             return
 
         if os.path.exists(result.split("file://")[-1]):
@@ -309,14 +280,9 @@ class _ImportToStore(task.Task):
         #     os.rename(file_path, image_path)
         #
         # image_import.set_image_data(image, image_path, None)
-        try:
-            image_import.set_image_data(image,
-                                        file_path or self.uri, self.task_id)
-        except IOError as e:
-            msg = (_('Uploading the image failed due to: %(exc)s') %
-                   {'exc': encodeutils.exception_to_unicode(e)})
-            LOG.error(msg)
-            raise exception.UploadException(message=msg)
+
+        image_import.set_image_data(image, file_path or self.uri, None)
+
         # NOTE(flaper87): We need to save the image again after the locations
         # have been set in the image.
         self.image_repo.save(image)
@@ -371,19 +337,16 @@ class _CompleteTask(task.Task):
 
             # TODO(nikhil): need to bring back save_and_reraise_exception when
             # necessary
-            log_msg = _LE("Task ID %(task_id)s failed. Error: %(exc_type)s: "
-                          "%(e)s")
-            LOG.exception(log_msg, {'exc_type': six.text_type(type(e)),
-                                    'e': encodeutils.exception_to_unicode(e),
-                                    'task_id': task.task_id})
+            err_msg = ("Error: " + six.text_type(type(e)) + ': ' +
+                       common_utils.exception_to_str(e))
+            log_msg = err_msg + _LE("Task ID %s") % task.task_id
+            LOG.exception(log_msg)
 
-            err_msg = _("Error: %(exc_type)s: %(e)s")
-            task.fail(err_msg % {'exc_type': six.text_type(type(e)),
-                                 'e': encodeutils.exception_to_unicode(e)})
+            task.fail(err_msg)
         finally:
             self.task_repo.save(task)
 
-        LOG.info(_LI("%(task_id)s of %(task_type)s completed"),
+        LOG.info(_LI("%(task_id)s of %(task_type)s completed") %
                  {'task_id': self.task_id, 'task_type': self.task_type})
 
 
@@ -396,8 +359,7 @@ def _get_import_flows(**kwargs):
     # Future patches will keep using NamedExtensionManager but they'll
     # rely on a config option to control this process.
     extensions = named.NamedExtensionManager('glance.flows.import',
-                                             names=['ovf_process',
-                                                    'convert',
+                                             names=['convert',
                                                     'introspect'],
                                              name_order=True,
                                              invoke_on_load=True,
@@ -462,16 +424,15 @@ def get_flow(**kwargs):
 
             # NOTE(flaper87): Since this is an "optional" task but required
             # when `limbo` is executed, we're adding it in its own subflow
-            # to isolate it from the rest of the flow.
+            # to isolat it from the rest of the flow.
             delete_flow = lf.Flow(task_type).add(_DeleteFromFS(task_id,
                                                                task_type))
             flow.add(delete_flow)
         else:
             flow.add(import_to_store)
-    except exception.BadTaskConfiguration as exc:
+    except exception.BadTaskConfiguration:
         # NOTE(flaper87): If something goes wrong with the load of
         # import tasks, make sure we go on.
-        LOG.error(_LE('Bad task configuration: %s'), exc.message)
         flow.add(import_to_store)
 
     flow.add(
