@@ -21,22 +21,26 @@ from oslo_config import cfg
 from taskflow.patterns import linear_flow as lf
 from taskflow import task
 
-from glance.i18n import _, _LW
+from glance import i18n
 
+_ = i18n._
+_LI = i18n._LI
+_LE = i18n._LE
+_LW = i18n._LW
 LOG = logging.getLogger(__name__)
 
 convert_task_opts = [
     cfg.StrOpt('conversion_format',
-               choices=('qcow2', 'raw', 'vmdk'),
+               default=None,
+               choices=('qcow2', 'raw'),
                help=_("The format to which images will be automatically "
-                      "converted. When using the RBD backend, this should be "
-                      "set to 'raw'")),
+                      "converted. " "Can be 'qcow2' or 'raw'.")),
 ]
 
 CONF = cfg.CONF
 
 # NOTE(flaper87): Registering under the taskflow_executor section
-# for now. It seems a waste to have a whole section dedicated to a
+# for now. It seems a waste to have a whole section dedidcated to a
 # single task with a single option.
 CONF.register_opts(convert_task_opts, group='taskflow_executor')
 
@@ -92,16 +96,10 @@ class _Convert(task.Task):
 
         fs_path = result.split("file://")[-1]
         if os.path.exists(fs_path):
-            os.remove(fs_path)
+            os.path.remove(fs_path)
 
 
 def get_flow(**kwargs):
-    """Return task flow for converting images to different formats.
-
-    :param task_id: Task ID.
-    :param task_type: Type of the task.
-    :param image_repo: Image repository used.
-    """
     task_id = kwargs.get('task_id')
     task_type = kwargs.get('task_type')
     image_repo = kwargs.get('image_repo')
