@@ -21,9 +21,8 @@ Utility methods for working with WSGI servers
 """
 from __future__ import print_function
 
-import datetime
 import errno
-import json
+import functools
 import os
 import signal
 import sys
@@ -34,7 +33,12 @@ from eventlet.green import socket
 from eventlet.green import ssl
 import eventlet.greenio
 import eventlet.wsgi
-from oslo.config import cfg
+import glance_store
+from oslo.serialization import jsonutils
+from oslo_concurrency import processutils
+from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_log import loggers
 import routes
 import routes.middleware
 import six
@@ -45,11 +49,13 @@ from webob import multidict
 from glance.common import exception
 from glance.common import utils
 from glance import i18n
-from glance.openstack.common import jsonutils
-import glance.openstack.common.log as logging
-from glance.openstack.common import processutils
 
 
+_ = i18n._
+_LE = i18n._LE
+_LI = i18n._LI
+_LW = i18n._LW
+
 bind_opts = [
     cfg.StrOpt('bind_host', default='0.0.0.0',
                help=_('Address to bind the server.  Useful when '
@@ -79,19 +85,25 @@ eventlet_opts = [
                help=_('The number of child process workers that will be '
                       'created to service requests. The default will be '
                       'equal to the number of CPUs available.')),
-    cfg.StrOpt('eventlet_hub', default='poll',
-               help=_('Name of eventlet hub to use. Traditionally, we have '
-                      'only supported \'poll\', however \'selects\' may be '
-                      'appropriate for some platforms. See '
-                      'http://eventlet.net/doc/hubs.html for more details.')),
     cfg.IntOpt('max_header_line', default=16384,
                help=_('Maximum line size of message headers to be accepted. '
                       'max_header_line may need to be increased when using '
                       'large tokens (typically those generated by the '
                       'Keystone v3 API with big service catalogs')),
     cfg.BoolOpt('http_keepalive', default=True,
-                help=_('If False, closes the client socket connection '
-                       'explicitly.')),
+                help=_('If False, server will return the header '
+                       '"Connection: close", '
+                       'If True, server will return "Connection: Keep-Alive" '
+                       'in its responses. In order to close the client socket '
+                       'connection explicitly after the response is sent and '
+                       'read successfully by the client, you simply have to '
+                       'set this option to False when you create a wsgi '
+                       'server.')),
+    cfg.IntOpt('client_socket_timeout', default=0,
+               help=_('Timeout for client connections\' socket operations. '
+                      'If an incoming connection is idle for this number of '
+                      'seconds it will be closed. A value of \'0\' means '
+                      'wait forever.')),
 ]
 
 profiler_opts = [
@@ -110,12 +122,38 @@ CONF.register_opts(socket_opts)
 CONF.register_opts(eventlet_opts)
 CONF.register_opts(profiler_opts, group="profiler")
 
+ASYNC_EVENTLET_THREAD_POOL_LIST = []
+
 
 def get_bind_addr(default_port=None):
     """Return the host and port to bind to."""
     return (CONF.bind_host, CONF.bind_port or default_port)
 
 
+def ssl_wrap_socket(sock):
+    """
+    Wrap an existing socket in SSL
+
+    :param sock: non-SSL socket to wrap
+
+    :returns: An SSL wrapped socket
+    """
+    utils.validate_key_cert(CONF.key_file, CONF.cert_file)
+
+    ssl_kwargs = {
+        'server_side': True,
+        'certfile': CONF.cert_file,
+        'keyfile': CONF.key_file,
+        'cert_reqs': ssl.CERT_NONE,
+    }
+
+    if CONF.ca_file:
+        ssl_kwargs['ca_certs'] = CONF.ca_file
+        ssl_kwargs['cert_reqs'] = ssl.CERT_REQUIRED
+
+    return ssl.wrap_socket(sock, **ssl_kwargs)
+
+
 def get_socket(default_port):
     """
     Bind socket to bind ip:port in conf
@@ -140,43 +178,20 @@ def get_socket(default_port):
         if addr[0] in (socket.AF_INET, socket.AF_INET6)
     ][0]
 
-    cert_file = CONF.cert_file
-    key_file = CONF.key_file
-    use_ssl = cert_file or key_file
-    if use_ssl and (not cert_file or not key_file):
+    use_ssl = CONF.key_file or CONF.cert_file
+    if use_ssl and (not CONF.key_file or not CONF.cert_file):
         raise RuntimeError(_("When running server in SSL mode, you must "
                              "specify both a cert_file and key_file "
                              "option value in your configuration file"))
 
-    def wrap_ssl(sock):
-        utils.validate_key_cert(key_file, cert_file)
-
-        ssl_kwargs = {
-            'server_side': True,
-            'certfile': cert_file,
-            'keyfile': key_file,
-            'cert_reqs': ssl.CERT_NONE,
-        }
-
-        if CONF.ca_file:
-            ssl_kwargs['ca_certs'] = CONF.ca_file
-            ssl_kwargs['cert_reqs'] = ssl.CERT_REQUIRED
-
-        return ssl.wrap_socket(sock, **ssl_kwargs)
-
     sock = utils.get_test_suite_socket()
     retry_until = time.time() + 30
 
-    if sock and use_ssl:
-        sock = wrap_ssl(sock)
     while not sock and time.time() < retry_until:
         try:
             sock = eventlet.listen(bind_addr,
                                    backlog=CONF.backlog,
                                    family=address_family)
-            if use_ssl:
-                sock = wrap_ssl(sock)
-
         except socket.error as err:
             if err.args[0] != errno.EADDRINUSE:
                 raise
@@ -186,48 +201,70 @@ def get_socket(default_port):
                              " trying for 30 seconds") %
                            {'host': bind_addr[0],
                             'port': bind_addr[1]})
-    sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
-    # in my experience, sockets can hang around forever without keepalive
-    sock.setsockopt(socket.SOL_SOCKET, socket.SO_KEEPALIVE, 1)
-
-    # This option isn't available in the OS X version of eventlet
-    if hasattr(socket, 'TCP_KEEPIDLE'):
-        sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_KEEPIDLE,
-                        CONF.tcp_keepidle)
 
     return sock
 
 
 def set_eventlet_hub():
     try:
-        eventlet.hubs.use_hub(cfg.CONF.eventlet_hub)
+        eventlet.hubs.use_hub('poll')
     except Exception:
-        msg = _("eventlet '%s' hub is not available on this platform")
-        raise exception.WorkerCreationFailure(
-            reason=msg % cfg.CONF.eventlet_hub)
+        try:
+            eventlet.hubs.use_hub('selects')
+        except Exception:
+            msg = _("eventlet 'poll' nor 'selects' hubs are available "
+                    "on this platform")
+            raise exception.WorkerCreationFailure(
+                reason=msg)
+
+
+def initialize_glance_store():
+    """Initialize glance store."""
+    glance_store.register_opts(CONF)
+    glance_store.create_stores(CONF)
+    glance_store.verify_default_store()
+
+
+def get_asynchronous_eventlet_pool(size=1000):
+    """Return eventlet pool to caller.
+
+    Also store pools created in global list, to wait on
+    it after getting signal for graceful shutdown.
+
+    :param size: eventlet pool size
+    :returns: eventlet pool
+    """
+    global ASYNC_EVENTLET_THREAD_POOL_LIST
+
+    pool = eventlet.GreenPool(size=size)
+    # Add pool to global ASYNC_EVENTLET_THREAD_POOL_LIST
+    ASYNC_EVENTLET_THREAD_POOL_LIST.append(pool)
+
+    return pool
 
 
 class Server(object):
-    """Server class to manage multiple WSGI sockets and applications."""
+    """Server class to manage multiple WSGI sockets and applications.
 
-    def __init__(self, threads=1000):
-        eventlet.wsgi.MAX_HEADER_LINE = CONF.max_header_line
+    This class requires initialize_glance_store set to True if
+    glance store needs to be initialized.
+    """
+    def __init__(self, threads=1000, initialize_glance_store=False):
+        os.umask(0o27)  # ensure files are created with the correct privileges
+        self._logger = logging.getLogger("eventlet.wsgi.server")
+        self._wsgi_logger = loggers.WritableLogger(self._logger)
         self.threads = threads
-        self.children = []
+        self.children = set()
+        self.stale_children = set()
         self.running = True
-
-    def start(self, application, default_port):
-        """
-        Run a WSGI server with the given application.
-
-        :param application: The application to be run in the WSGI server
-        :param default_port: Port to bind to if none is specified in conf
-        """
-        pgid = os.getpid()
+        # NOTE(abhishek): Allows us to only re-initialize glance_store when
+        # the API's configuration reloads.
+        self.initialize_glance_store = initialize_glance_store
+        self.pgid = os.getpid()
         try:
             # NOTE(flaper87): Make sure this process
             # runs in its own process group.
-            os.setpgid(pgid, pgid)
+            os.setpgid(self.pgid, self.pgid)
         except OSError:
             # NOTE(flaper87): When running glance-control,
             # (glance's functional tests, for example)
@@ -238,69 +275,135 @@ class Server(object):
             #
             # Running glance-(api|registry) is safe and
             # shouldn't raise any error here.
-            pgid = 0
+            self.pgid = 0
 
-        def kill_children(*args):
-            """Kills the entire process group."""
-            signal.signal(signal.SIGTERM, signal.SIG_IGN)
-            signal.signal(signal.SIGINT, signal.SIG_IGN)
-            self.running = False
-            os.killpg(pgid, signal.SIGTERM)
+    def hup(self, *args):
+        """
+        Reloads configuration files with zero down time
+        """
+        signal.signal(signal.SIGHUP, signal.SIG_IGN)
+        raise exception.SIGHUPInterrupt
 
-        def hup(*args):
-            """
-            Shuts down the server, but allows running requests to complete
-            """
-            signal.signal(signal.SIGHUP, signal.SIG_IGN)
-            self.running = False
+    def kill_children(self, *args):
+        """Kills the entire process group."""
+        signal.signal(signal.SIGTERM, signal.SIG_IGN)
+        signal.signal(signal.SIGINT, signal.SIG_IGN)
+        self.running = False
+        os.killpg(self.pgid, signal.SIGTERM)
 
+    def start(self, application, default_port):
+        """
+        Run a WSGI server with the given application.
+
+        :param application: The application to be run in the WSGI server
+        :param default_port: Port to bind to if none is specified in conf
+        """
         self.application = application
-        self.sock = get_socket(default_port)
-
-        os.umask(0o27)  # ensure files are created with the correct privileges
-        self.logger = logging.getLogger('glance.wsgi.server')
+        self.default_port = default_port
+        self.configure()
+        self.start_wsgi()
 
+    def start_wsgi(self):
         if CONF.workers == 0:
             # Useful for profiling, test, debug etc.
             self.pool = self.create_pool()
             self.pool.spawn_n(self._single_run, self.application, self.sock)
             return
         else:
-            self.logger.info(_("Starting %d workers") % CONF.workers)
-            signal.signal(signal.SIGTERM, kill_children)
-            signal.signal(signal.SIGINT, kill_children)
-            signal.signal(signal.SIGHUP, hup)
+            LOG.info(_LI("Starting %d workers") % CONF.workers)
+            signal.signal(signal.SIGTERM, self.kill_children)
+            signal.signal(signal.SIGINT, self.kill_children)
+            signal.signal(signal.SIGHUP, self.hup)
             while len(self.children) < CONF.workers:
                 self.run_child()
 
     def create_pool(self):
         return eventlet.GreenPool(size=self.threads)
 
+    def _remove_children(self, pid):
+        if pid in self.children:
+            self.children.remove(pid)
+            LOG.info(_LI('Removed dead child %s') % pid)
+        elif pid in self.stale_children:
+            self.stale_children.remove(pid)
+            LOG.info(_LI('Removed stale child %s') % pid)
+        else:
+            LOG.warn(_LW('Unrecognised child %s') % pid)
+
+    def _verify_and_respawn_children(self, pid, status):
+        if len(self.stale_children) == 0:
+            LOG.debug('No stale children')
+        if os.WIFEXITED(status) and os.WEXITSTATUS(status) != 0:
+            LOG.error(_LE('Not respawning child %d, cannot '
+                          'recover from termination') % pid)
+            if not self.children and not self.stale_children:
+                LOG.info(
+                    _LI('All workers have terminated. Exiting'))
+                self.running = False
+        else:
+            if len(self.children) < CONF.workers:
+                self.run_child()
+
     def wait_on_children(self):
         while self.running:
             try:
                 pid, status = os.wait()
                 if os.WIFEXITED(status) or os.WIFSIGNALED(status):
-                    self.logger.info(_('Removing dead child %s') % pid)
-                    self.children.remove(pid)
-                    if os.WIFEXITED(status) and os.WEXITSTATUS(status) != 0:
-                        self.logger.error(_('Not respawning child %d, cannot '
-                                            'recover from termination') % pid)
-                        if not self.children:
-                            self.logger.info(
-                                _('All workers have terminated. Exiting'))
-                            self.running = False
-                    else:
-                        self.run_child()
+                    self._remove_children(pid)
+                    self._verify_and_respawn_children(pid, status)
             except OSError as err:
                 if err.errno not in (errno.EINTR, errno.ECHILD):
                     raise
             except KeyboardInterrupt:
-                self.logger.info(_('Caught keyboard interrupt. Exiting.'))
+                LOG.info(_LI('Caught keyboard interrupt. Exiting.'))
                 break
+            except exception.SIGHUPInterrupt:
+                self.reload()
+                continue
         eventlet.greenio.shutdown_safe(self.sock)
         self.sock.close()
-        self.logger.debug('Exited')
+        LOG.debug('Exited')
+
+    def configure(self, old_conf=None, has_changed=None):
+        """
+        Apply configuration settings
+
+        :param old_conf: Cached old configuration settings (if any)
+        :param has changed: callable to determine if a parameter has changed
+        """
+        eventlet.wsgi.MAX_HEADER_LINE = CONF.max_header_line
+        self.client_socket_timeout = CONF.client_socket_timeout or None
+        self.configure_socket(old_conf, has_changed)
+        if self.initialize_glance_store:
+            initialize_glance_store()
+
+    def reload(self):
+        """
+        Reload and re-apply configuration settings
+
+        Existing child processes are sent a SIGHUP signal
+        and will exit after completing existing requests.
+        New child processes, which will have the updated
+        configuration, are spawned. This allows preventing
+        interruption to the service.
+        """
+        def _has_changed(old, new, param):
+            old = old.get(param)
+            new = getattr(new, param)
+            return (new != old)
+
+        old_conf = utils.stash_conf_values()
+        has_changed = functools.partial(_has_changed, old_conf, CONF)
+        CONF.reload_config_files()
+        os.killpg(self.pgid, signal.SIGHUP)
+        self.stale_children = self.children
+        self.children = set()
+
+        # Ensure any logging config changes are picked up
+        logging.setup(CONF, 'glance')
+
+        self.configure(old_conf, has_changed)
+        self.start_wsgi()
 
     def wait(self):
         """Wait until all servers have completed running."""
@@ -313,22 +416,32 @@ class Server(object):
             pass
 
     def run_child(self):
+        def child_hup(*args):
+            """Shuts down child processes, existing requests are handled."""
+            signal.signal(signal.SIGHUP, signal.SIG_IGN)
+            eventlet.wsgi.is_accepting = False
+            self.sock.close()
+
         pid = os.fork()
         if pid == 0:
-            signal.signal(signal.SIGHUP, signal.SIG_DFL)
+            signal.signal(signal.SIGHUP, child_hup)
             signal.signal(signal.SIGTERM, signal.SIG_DFL)
             # ignore the interrupt signal to avoid a race whereby
             # a child worker receives the signal before the parent
             # and is respawned unnecessarily as a result
             signal.signal(signal.SIGINT, signal.SIG_IGN)
+            # The child has no need to stash the unwrapped
+            # socket, and the reference prevents a clean
+            # exit on sighup
+            self._sock = None
             self.run_server()
-            self.logger.info(_('Child %d exiting normally') % os.getpid())
-            # self.pool.waitall() has been called by run_server, so
-            # its safe to exit here
+            LOG.info(_LI('Child %d exiting normally') % os.getpid())
+            # self.pool.waitall() is now called in wsgi's server so
+            # it's safe to exit here
             sys.exit(0)
         else:
-            self.logger.info(_('Started child %s') % pid)
-            self.children.append(pid)
+            LOG.info(_LI('Started child %s') % pid)
+            self.children.add(pid)
 
     def run_server(self):
         """Run a WSGI server."""
@@ -341,22 +454,100 @@ class Server(object):
         try:
             eventlet.wsgi.server(self.sock,
                                  self.application,
-                                 log=logging.WritableLogger(self.logger),
+                                 log=self._wsgi_logger,
                                  custom_pool=self.pool,
                                  debug=False,
-                                 keepalive=CONF.http_keepalive)
+                                 keepalive=CONF.http_keepalive,
+                                 socket_timeout=self.client_socket_timeout)
         except socket.error as err:
             if err[0] != errno.EINVAL:
                 raise
-        self.pool.waitall()
+
+        # waiting on async pools
+        if ASYNC_EVENTLET_THREAD_POOL_LIST:
+            for pool in ASYNC_EVENTLET_THREAD_POOL_LIST:
+                pool.waitall()
 
     def _single_run(self, application, sock):
         """Start a WSGI server in a new green thread."""
-        self.logger.info(_("Starting single process server"))
+        LOG.info(_LI("Starting single process server"))
         eventlet.wsgi.server(sock, application, custom_pool=self.pool,
-                             log=logging.WritableLogger(self.logger),
+                             log=self._wsgi_logger,
                              debug=False,
-                             keepalive=CONF.http_keepalive)
+                             keepalive=CONF.http_keepalive,
+                             socket_timeout=self.client_socket_timeout)
+
+    def configure_socket(self, old_conf=None, has_changed=None):
+        """
+        Ensure a socket exists and is appropriately configured.
+
+        This function is called on start up, and can also be
+        called in the event of a configuration reload.
+
+        When called for the first time a new socket is created.
+        If reloading and either bind_host or bind port have been
+        changed the existing socket must be closed and a new
+        socket opened (laws of physics).
+
+        In all other cases (bind_host/bind_port have not changed)
+        the existing socket is reused.
+
+        :param old_conf: Cached old configuration settings (if any)
+        :param has changed: callable to determine if a parameter has changed
+        """
+        # Do we need a fresh socket?
+        new_sock = (old_conf is None or (
+                    has_changed('bind_host') or
+                    has_changed('bind_port')))
+        # Will we be using https?
+        use_ssl = not (not CONF.cert_file or not CONF.key_file)
+        # Were we using https before?
+        old_use_ssl = (old_conf is not None and not (
+                       not old_conf.get('key_file') or
+                       not old_conf.get('cert_file')))
+        # Do we now need to perform an SSL wrap on the socket?
+        wrap_sock = use_ssl is True and (old_use_ssl is False or new_sock)
+        # Do we now need to perform an SSL unwrap on the socket?
+        unwrap_sock = use_ssl is False and old_use_ssl is True
+
+        if new_sock:
+            self._sock = None
+            if old_conf is not None:
+                self.sock.close()
+            _sock = get_socket(self.default_port)
+            _sock.setsockopt(socket.SOL_SOCKET,
+                             socket.SO_REUSEADDR, 1)
+            # sockets can hang around forever without keepalive
+            _sock.setsockopt(socket.SOL_SOCKET,
+                             socket.SO_KEEPALIVE, 1)
+            self._sock = _sock
+
+        if wrap_sock:
+            self.sock = ssl_wrap_socket(self._sock)
+
+        if unwrap_sock:
+            self.sock = self._sock
+
+        if new_sock and not use_ssl:
+            self.sock = self._sock
+
+        # Pick up newly deployed certs
+        if old_conf is not None and use_ssl is True and old_use_ssl is True:
+            if has_changed('cert_file') or has_changed('key_file'):
+                utils.validate_key_cert(CONF.key_file, CONF.cert_file)
+            if has_changed('cert_file'):
+                self.sock.certfile = CONF.cert_file
+            if has_changed('key_file'):
+                self.sock.keyfile = CONF.key_file
+
+        if new_sock or (old_conf is not None and has_changed('tcp_keepidle')):
+            # This option isn't available in the OS X version of eventlet
+            if hasattr(socket, 'TCP_KEEPIDLE'):
+                self.sock.setsockopt(socket.IPPROTO_TCP, socket.TCP_KEEPIDLE,
+                                     CONF.tcp_keepidle)
+
+        if old_conf is not None and has_changed('backlog'):
+            self.sock.listen(CONF.backlog)
 
 
 class Middleware(object):
@@ -438,7 +629,7 @@ class Debug(Middleware):
             sys.stdout.write(part)
             sys.stdout.flush()
             yield part
-        print
+        print()
 
 
 class APIMapper(routes.Mapper):
@@ -572,26 +763,32 @@ class Request(webob.Request):
 
 
 class JSONRequestDeserializer(object):
+    valid_transfer_encoding = frozenset(['chunked', 'compress', 'deflate',
+                                         'gzip', 'identity'])
+
     def has_body(self, request):
         """
         Returns whether a Webob.Request object will possess an entity body.
 
         :param request:  Webob.Request object
         """
-        if 'transfer-encoding' in request.headers:
+        request_encoding = request.headers.get('transfer-encoding', '').lower()
+        is_valid_encoding = request_encoding in self.valid_transfer_encoding
+        if is_valid_encoding and request.is_body_readable:
             return True
         elif request.content_length > 0:
             return True
 
         return False
 
-    def _sanitizer(self, obj):
+    @staticmethod
+    def _sanitizer(obj):
         """Sanitizer method that will be passed to jsonutils.loads."""
         return obj
 
     def from_json(self, datastring):
         try:
-            return json.loads(datastring, object_hook=self._sanitizer)
+            return jsonutils.loads(datastring, object_hook=self._sanitizer)
         except ValueError:
             msg = _('Malformed JSON in request body.')
             raise webob.exc.HTTPBadRequest(explanation=msg)
@@ -607,15 +804,11 @@ class JSONResponseSerializer(object):
 
     def _sanitizer(self, obj):
         """Sanitizer method that will be passed to jsonutils.dumps."""
-        if isinstance(obj, datetime.datetime):
-            return obj.isoformat()
         if hasattr(obj, "to_dict"):
             return obj.to_dict()
         if isinstance(obj, multidict.MultiDict):
             return obj.mixed()
-        if isinstance(obj, set):
-            return list(obj)
-        return obj
+        return jsonutils.to_primitive(obj)
 
     def to_json(self, data):
         return jsonutils.dumps(data, default=self._sanitizer)
