@@ -14,8 +14,6 @@
 
 import uuid
 
-import six
-
 import glance.artifacts as ga
 from glance.common import exception as exc
 from glance import context
@@ -283,9 +281,9 @@ class ArtifactTests(object):
                                           TYPE_NAME, TYPE_VERSION)
         self.assertIsNotNone(res)
 
-        created = self.db_api.artifact_get(
-            self.context, res['id'], TYPE_NAME, TYPE_VERSION,
-            show_level=ga.Showlevel.DIRECT)
+        created = self.db_api. \
+            artifact_get(self.context, res['id'], TYPE_NAME, TYPE_VERSION,
+                         show_level=ga.Showlevel.DIRECT)
         bd_dependencies = created['dependencies']
         self.assertEqual(1, len(bd_dependencies))
         # now try to update artifact with the same dependency
@@ -306,9 +304,9 @@ class ArtifactTests(object):
                                           TYPE_NAME, TYPE_VERSION)
         self.assertIsNotNone(res)
 
-        created = self.db_api.artifact_get(
-            self.context, res['id'], TYPE_NAME, TYPE_VERSION,
-            show_level=ga.Showlevel.DIRECT)
+        created = self.db_api. \
+            artifact_get(self.context, res['id'], TYPE_NAME, TYPE_VERSION,
+                         show_level=ga.Showlevel.DIRECT)
         bd_dependencies = created['dependencies']
         self.assertEqual(1, len(bd_dependencies))
 
@@ -317,9 +315,9 @@ class ArtifactTests(object):
             res['id'], TYPE_NAME, TYPE_VERSION
         )
 
-        res = self.db_api.artifact_get(
-            self.context, res['id'], TYPE_NAME, TYPE_VERSION,
-            show_level=ga.Showlevel.TRANSITIVE)
+        res = self.db_api. \
+            artifact_get(self.context, res['id'], TYPE_NAME, TYPE_VERSION,
+                         show_level=ga.Showlevel.TRANSITIVE)
         self.assertIsNotNone(res.pop('created_at'))
         self.assertIsNotNone(res.pop('updated_at'))
 
@@ -332,8 +330,8 @@ class ArtifactTests(object):
         self.assertIsNotNone(tags)
         self.assertEqual(set(['gugugu', 'lalala']), set(tags))
 
-        tags = (res['dependencies']['new->2'][0]['dependencies']['2->1'][0].
-                pop('tags', None))
+        tags = res['dependencies']['new->2'][0]['dependencies']['2->1'][0]\
+            .pop('tags', None)
         self.assertIsNotNone(tags)
         self.assertEqual(set(['gugugu', 'lalala']), set(tags))
 
@@ -515,7 +513,7 @@ class ArtifactTests(object):
         self.assertIsNotNone(res['published_at'])
         published_at = res['published_at']
         expected['published_at'] = published_at
-        for key, value in six.iteritems(expected):
+        for key, value in expected.iteritems():
             self.assertEqual(expected[key], res[key])
 
     def test_artifact_get_all(self):
@@ -560,8 +558,9 @@ class ArtifactTests(object):
 
         self.assertRaises(KeyError, lambda: artifacts[0]['properties'])
 
-        artifacts = self.db_api.artifact_get_all(
-            self.context, show_level=ga.Showlevel.BASIC)
+        artifacts = self.db_api. \
+            artifact_get_all(self.context,
+                             show_level=ga.Showlevel.BASIC)
         self.assertEqual(2, len(artifacts))
         self.assertEqual(4, len(artifacts[0]['properties']))
 
@@ -577,15 +576,15 @@ class ArtifactTests(object):
         artifacts = self.db_api.artifact_get_all(self.context)
         self.assertEqual(3, len(artifacts))
 
-        filters = {'tags': [{
-            'value': 'notag',
-        }]}
+        filters = {'tags': {
+            'value': ['notag'],
+        }}
         artifacts = self.db_api.artifact_get_all(self.context, filters=filters)
         self.assertEqual(0, len(artifacts))
 
-        filters = {'tags': [{
-            'value': 'lalala',
-        }]}
+        filters = {'tags': {
+            'value': ['lalala'],
+        }}
         artifacts = self.db_api.artifact_get_all(self.context, filters=filters)
         self.assertEqual(2, len(artifacts))
         for artifact in artifacts:
@@ -619,46 +618,46 @@ class ArtifactTests(object):
         self.db_api.artifact_create(self.context, artifact,
                                     TYPE_NAME, TYPE_VERSION)
 
-        filters = {'propname2': [{
+        filters = {'propname2': {
             'value': 4,
             'operator': 'GT',
-            'type': 'int'}]}
+            'type': 'int'}}
         artifacts = self.db_api.artifact_get_all(self.context, filters=filters)
         self.assertEqual(2, len(artifacts))
         for artifact in artifacts:
             self.assertIn(artifact['name'], ['TestArtifact1', 'TestArtifact2'])
 
         # position hasn't been set
-        filters = {'proparray': [{
+        filters = {'proparray': {
             'value': 6,
             'operator': 'LE',
-            'type': 'int'}]}
+            'type': 'int'}}
         artifacts = self.db_api.artifact_get_all(self.context, filters=filters)
         self.assertEqual(0, len(artifacts))
         for artifact in artifacts:
             self.assertIn(artifact['name'], ['TestArtifact1', 'TestArtifact2'])
 
         # position has been set
-        filters = {'proparray': [{
+        filters = {'proparray': {
             'value': 6,
             'position': 0,
             'operator': 'LE',
-            'type': 'int'}]}
+            'type': 'int'}}
         artifacts = self.db_api.artifact_get_all(self.context, filters=filters)
         self.assertEqual(2, len(artifacts))
         for artifact in artifacts:
             self.assertIn(artifact['name'], ['TestArtifact1', 'TestArtifact2'])
 
-        filters = {'proparray': [{
+        filters = {'proparray': {
             'value': 6,
             'operator': 'IN',
-            'type': 'int'}]}
+            'type': 'int'}}
         artifacts = self.db_api.artifact_get_all(self.context, filters=filters)
         self.assertEqual(2, len(artifacts))
         for artifact in artifacts:
             self.assertIn(artifact['name'], ['TestArtifact1', 'TestArtifact2'])
 
-        filters = {'name': [{'value': 'new_artifact'}]}
+        filters = {'name': {'value': 'new_artifact'}}
         artifacts = self.db_api.artifact_get_all(self.context,
                                                  filters=filters,
                                                  show_level=ga.Showlevel.BASIC)
@@ -668,10 +667,10 @@ class ArtifactTests(object):
         for prop in artifact['properties'].keys():
             self.assertNotEqual('proptext', prop)
 
-        filters = {'propname2': [{
+        filters = {'propname2': {
             'value': 4,
             'operator': 'FOO',
-            'type': 'int'}]}
+            'type': 'int'}}
         self.assertRaises(
             exc.ArtifactUnsupportedPropertyOperator,
             self.db_api.artifact_get_all, self.context, filters=filters)
