@@ -13,21 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
 import mock
 import os
+import urllib2
 
 import glance_store
-from oslo_concurrency import processutils as putils
 from oslo_config import cfg
-import six
-from six.moves import urllib
+from six.moves import cStringIO
 from taskflow import task
-from taskflow.types import failure
 
 import glance.async.flows.base_import as import_flow
 from glance.async import taskflow_executor
-from glance.async import utils as async_utils
 from glance.common.scripts.image_import import main as image_import
 from glance.common.scripts import utils as script_utils
 from glance.common import utils
@@ -87,14 +83,6 @@ class TestImportTask(test_utils.BaseTestCase):
                                                task_time_to_live=task_ttl,
                                                task_input=task_input)
 
-    def _assert_qemu_process_limits(self, exec_mock):
-        # NOTE(hemanthm): Assert that process limits are being applied
-        # on "qemu-img info" calls. See bug #1449062 for more details.
-        kw_args = exec_mock.call_args[1]
-        self.assertIn('prlimit', kw_args)
-        self.assertEqual(async_utils.QEMU_IMG_PROC_LIMITS,
-                         kw_args.get('prlimit'))
-
     def test_import_flow(self):
         self.config(engine_mode='serial',
                     group='taskflow_executor')
@@ -117,26 +105,17 @@ class TestImportTask(test_utils.BaseTestCase):
         img_factory.new_image.side_effect = create_image
 
         with mock.patch.object(script_utils, 'get_image_data_iter') as dmock:
-            dmock.return_value = six.BytesIO(b"TEST_IMAGE")
-
-            with mock.patch.object(putils, 'trycmd') as tmock:
-                tmock.return_value = (json.dumps({
-                    'format': 'qcow2',
-                }), None)
-
-                executor.begin_processing(self.task.task_id)
-                image_path = os.path.join(self.test_dir, self.image.image_id)
-                tmp_image_path = os.path.join(self.work_dir,
-                                              "%s.tasks_import" % image_path)
-
-                self.assertFalse(os.path.exists(tmp_image_path))
-                self.assertTrue(os.path.exists(image_path))
-                self.assertEqual(1, len(list(self.image.locations)))
-                self.assertEqual("file://%s/%s" % (self.test_dir,
-                                                   self.image.image_id),
-                                 self.image.locations[0]['url'])
-
-                self._assert_qemu_process_limits(tmock)
+            dmock.return_value = cStringIO("TEST_IMAGE")
+            executor.begin_processing(self.task.task_id)
+            image_path = os.path.join(self.test_dir, self.image.image_id)
+            tmp_image_path = os.path.join(self.work_dir,
+                                          "%s.tasks_import" % image_path)
+            self.assertFalse(os.path.exists(tmp_image_path))
+            self.assertTrue(os.path.exists(image_path))
+            self.assertEqual(1, len(list(self.image.locations)))
+            self.assertEqual("file://%s/%s" % (self.test_dir,
+                                               self.image.image_id),
+                             self.image.locations[0]['url'])
 
     def test_import_flow_missing_work_dir(self):
         self.config(engine_mode='serial', group='taskflow_executor')
@@ -160,7 +139,7 @@ class TestImportTask(test_utils.BaseTestCase):
         img_factory.new_image.side_effect = create_image
 
         with mock.patch.object(script_utils, 'get_image_data_iter') as dmock:
-            dmock.return_value = six.BytesIO(b"TEST_IMAGE")
+            dmock.return_value = cStringIO("TEST_IMAGE")
 
             with mock.patch.object(import_flow._ImportToFS, 'execute') as emk:
                 executor.begin_processing(self.task.task_id)
@@ -172,93 +151,6 @@ class TestImportTask(test_utils.BaseTestCase):
                 self.assertFalse(os.path.exists(tmp_image_path))
                 self.assertTrue(os.path.exists(image_path))
 
-    def test_import_flow_revert_import_to_fs(self):
-        self.config(engine_mode='serial', group='taskflow_executor')
-
-        img_factory = mock.MagicMock()
-
-        executor = taskflow_executor.TaskExecutor(
-            self.context,
-            self.task_repo,
-            self.img_repo,
-            img_factory)
-
-        self.task_repo.get.return_value = self.task
-
-        def create_image(*args, **kwargs):
-            kwargs['image_id'] = UUID1
-            return self.img_factory.new_image(*args, **kwargs)
-
-        self.img_repo.get.return_value = self.image
-        img_factory.new_image.side_effect = create_image
-
-        with mock.patch.object(script_utils, 'get_image_data_iter') as dmock:
-            dmock.side_effect = RuntimeError
-
-            with mock.patch.object(import_flow._ImportToFS, 'revert') as rmock:
-                self.assertRaises(RuntimeError,
-                                  executor.begin_processing, self.task.task_id)
-                self.assertTrue(rmock.called)
-                self.assertIsInstance(rmock.call_args[1]['result'],
-                                      failure.Failure)
-
-                image_path = os.path.join(self.test_dir, self.image.image_id)
-                tmp_image_path = os.path.join(self.work_dir,
-                                              "%s.tasks_import" % image_path)
-                self.assertFalse(os.path.exists(tmp_image_path))
-                # Note(sabari): The image should not have been uploaded to
-                # the store as the flow failed before ImportToStore Task.
-                self.assertFalse(os.path.exists(image_path))
-
-    def test_import_flow_backed_file_import_to_fs(self):
-        self.config(engine_mode='serial', group='taskflow_executor')
-
-        img_factory = mock.MagicMock()
-
-        executor = taskflow_executor.TaskExecutor(
-            self.context,
-            self.task_repo,
-            self.img_repo,
-            img_factory)
-
-        self.task_repo.get.return_value = self.task
-
-        def create_image(*args, **kwargs):
-            kwargs['image_id'] = UUID1
-            return self.img_factory.new_image(*args, **kwargs)
-
-        self.img_repo.get.return_value = self.image
-        img_factory.new_image.side_effect = create_image
-
-        with mock.patch.object(script_utils, 'get_image_data_iter') as dmock:
-            dmock.return_value = six.BytesIO(b"TEST_IMAGE")
-
-            with mock.patch.object(putils, 'trycmd') as tmock:
-                tmock.return_value = (json.dumps({
-                    'backing-filename': '/etc/password'
-                }), None)
-
-                with mock.patch.object(import_flow._ImportToFS,
-                                       'revert') as rmock:
-                    self.assertRaises(RuntimeError,
-                                      executor.begin_processing,
-                                      self.task.task_id)
-                    self.assertTrue(rmock.called)
-                    self.assertIsInstance(rmock.call_args[1]['result'],
-                                          failure.Failure)
-                    self._assert_qemu_process_limits(tmock)
-
-                    image_path = os.path.join(self.test_dir,
-                                              self.image.image_id)
-
-                    fname = "%s.tasks_import" % image_path
-                    tmp_image_path = os.path.join(self.work_dir, fname)
-
-                    self.assertFalse(os.path.exists(tmp_image_path))
-                    # Note(sabari): The image should not have been uploaded to
-                    # the store as the flow failed before ImportToStore Task.
-                    self.assertFalse(os.path.exists(image_path))
-
     def test_import_flow_revert(self):
         self.config(engine_mode='serial',
                     group='taskflow_executor')
@@ -281,35 +173,22 @@ class TestImportTask(test_utils.BaseTestCase):
         img_factory.new_image.side_effect = create_image
 
         with mock.patch.object(script_utils, 'get_image_data_iter') as dmock:
-            dmock.return_value = six.BytesIO(b"TEST_IMAGE")
+            dmock.return_value = cStringIO("TEST_IMAGE")
 
-            with mock.patch.object(putils, 'trycmd') as tmock:
-                tmock.return_value = (json.dumps({
-                    'format': 'qcow2',
-                }), None)
+            with mock.patch.object(import_flow, "_get_import_flows") as imock:
+                imock.return_value = (x for x in [_ErrorTask()])
+                self.assertRaises(RuntimeError,
+                                  executor.begin_processing, self.task.task_id)
+                image_path = os.path.join(self.test_dir, self.image.image_id)
+                tmp_image_path = os.path.join(self.work_dir,
+                                              "%s.tasks_import" % image_path)
+                self.assertFalse(os.path.exists(tmp_image_path))
 
-                with mock.patch.object(import_flow,
-                                       "_get_import_flows") as imock:
-                    imock.return_value = (x for x in [_ErrorTask()])
-                    self.assertRaises(RuntimeError,
-                                      executor.begin_processing,
-                                      self.task.task_id)
-
-                    self._assert_qemu_process_limits(tmock)
-
-                    image_path = os.path.join(self.test_dir,
-                                              self.image.image_id)
-                    tmp_image_path = os.path.join(self.work_dir,
-                                                  ("%s.tasks_import" %
-                                                   image_path))
-                    self.assertFalse(os.path.exists(tmp_image_path))
-
-                    # NOTE(flaper87): Eventually, we want this to be assertTrue
-                    # The current issue is there's no way to tell taskflow to
-                    # continue on failures. That is, revert the subflow but
-                    # keep executing the parent flow. Under
-                    # discussion/development.
-                    self.assertFalse(os.path.exists(image_path))
+                # NOTE(flaper87): Eventually, we want this to be assertTrue.
+                # The current issue is there's no way to tell taskflow to
+                # continue on failures. That is, revert the subflow but keep
+                # executing the parent flow. Under discussion/development.
+                self.assertFalse(os.path.exists(image_path))
 
     def test_import_flow_no_import_flows(self):
         self.config(engine_mode='serial',
@@ -332,9 +211,9 @@ class TestImportTask(test_utils.BaseTestCase):
         self.img_repo.get.return_value = self.image
         img_factory.new_image.side_effect = create_image
 
-        with mock.patch.object(urllib.request, 'urlopen') as umock:
-            content = b"TEST_IMAGE"
-            umock.return_value = six.BytesIO(content)
+        with mock.patch.object(urllib2, 'urlopen') as umock:
+            content = "TEST_IMAGE"
+            umock.return_value = cStringIO(content)
 
             with mock.patch.object(import_flow, "_get_import_flows") as imock:
                 imock.return_value = (x for x in [])
@@ -346,7 +225,7 @@ class TestImportTask(test_utils.BaseTestCase):
                 self.assertTrue(os.path.exists(image_path))
                 self.assertEqual(1, umock.call_count)
 
-                with open(image_path, 'rb') as ifile:
+                with open(image_path) as ifile:
                     self.assertEqual(content, ifile.read())
 
     def test_create_image(self):
@@ -390,30 +269,23 @@ class TestImportTask(test_utils.BaseTestCase):
                                             'http://example.com/image.qcow2')
 
         with mock.patch.object(script_utils, 'get_image_data_iter') as dmock:
-            content = b"test"
-            dmock.return_value = [content]
+            dmock.return_value = "test"
 
-            with mock.patch.object(putils, 'trycmd') as tmock:
-                tmock.return_value = (json.dumps({
-                    'format': 'qcow2',
-                }), None)
+            image_id = UUID1
+            path = import_fs.execute(image_id)
+            reader, size = glance_store.get_from_backend(path)
+            self.assertEqual(4, size)
+            self.assertEqual(dmock.return_value, "".join(reader))
 
-                image_id = UUID1
-                path = import_fs.execute(image_id)
-                reader, size = glance_store.get_from_backend(path)
-                self.assertEqual(4, size)
-                self.assertEqual(content, b"".join(reader))
-
-                image_path = os.path.join(self.work_dir, image_id)
-                tmp_image_path = os.path.join(self.work_dir, image_path)
-                self.assertTrue(os.path.exists(tmp_image_path))
-                self._assert_qemu_process_limits(tmock)
+            image_path = os.path.join(self.work_dir, image_id)
+            tmp_image_path = os.path.join(self.work_dir, image_path)
+            self.assertTrue(os.path.exists(tmp_image_path))
 
     def test_delete_from_fs(self):
         delete_fs = import_flow._DeleteFromFS(self.task.task_id,
                                               self.task_type)
 
-        data = [b"test"]
+        data = "test"
 
         store = glance_store.get_store_from_scheme('file')
         path = glance_store.store_add_to_backend(mock.sentinel.image_id, data,
