@@ -15,13 +15,14 @@
 #    under the License.
 
 import datetime
+import gettext
 import socket
 
 from babel import localedata
 import eventlet.patcher
 import fixtures
-import gettext
 import mock
+from oslo.serialization import jsonutils
 import routes
 import six
 import webob
@@ -32,7 +33,6 @@ from glance.common import exception
 from glance.common import utils
 from glance.common import wsgi
 from glance import i18n
-from glance.openstack.common import jsonutils
 from glance.tests import utils as test_utils
 
 
@@ -65,8 +65,8 @@ class RequestTest(test_utils.BaseTestCase):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Content-Range"] = 'bytes 10-99/*'
         range_ = request.get_content_range()
-        self.assertEqual(range_.start, 10)
-        self.assertEqual(range_.stop, 100)  # non-inclusive
+        self.assertEqual(10, range_.start)
+        self.assertEqual(100, range_.stop)  # non-inclusive
         self.assertIsNone(range_.length)
 
     def test_content_range_invalid(self):
@@ -90,38 +90,38 @@ class RequestTest(test_utils.BaseTestCase):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Content-Type"] = "application/json; charset=UTF-8"
         result = request.get_content_type(('application/json',))
-        self.assertEqual(result, "application/json")
+        self.assertEqual("application/json", result)
 
     def test_content_type_from_accept_xml(self):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Accept"] = "application/xml"
         result = request.best_match_content_type()
-        self.assertEqual(result, "application/json")
+        self.assertEqual("application/json", result)
 
     def test_content_type_from_accept_json(self):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Accept"] = "application/json"
         result = request.best_match_content_type()
-        self.assertEqual(result, "application/json")
+        self.assertEqual("application/json", result)
 
     def test_content_type_from_accept_xml_json(self):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Accept"] = "application/xml, application/json"
         result = request.best_match_content_type()
-        self.assertEqual(result, "application/json")
+        self.assertEqual("application/json", result)
 
     def test_content_type_from_accept_json_xml_quality(self):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Accept"] = ("application/json; q=0.3, "
                                      "application/xml; q=0.9")
         result = request.best_match_content_type()
-        self.assertEqual(result, "application/json")
+        self.assertEqual("application/json", result)
 
     def test_content_type_accept_default(self):
         request = wsgi.Request.blank('/tests/123.unsupported')
         request.headers["Accept"] = "application/unsupported1"
         result = request.best_match_content_type()
-        self.assertEqual(result, "application/json")
+        self.assertEqual("application/json", result)
 
     def test_language_accept_default(self):
         request = wsgi.Request.blank('/tests/123')
@@ -242,13 +242,13 @@ class ResourceTest(test_utils.BaseTestCase):
         expected = {'action': 'update', 'id': 12}
         actual = wsgi.Resource(None, None, None).get_action_args(env)
 
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_get_action_args_invalid_index(self):
         env = {'wsgiorg.routing_args': []}
         expected = {}
         actual = wsgi.Resource(None, None, None).get_action_args(env)
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_get_action_args_del_controller_error(self):
         actions = {'format': None,
@@ -257,14 +257,14 @@ class ResourceTest(test_utils.BaseTestCase):
         env = {'wsgiorg.routing_args': [None, actions]}
         expected = {'action': 'update', 'id': 12}
         actual = wsgi.Resource(None, None, None).get_action_args(env)
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_get_action_args_del_format_error(self):
         actions = {'action': 'update', 'id': 12}
         env = {'wsgiorg.routing_args': [None, actions]}
         expected = {'action': 'update', 'id': 12}
         actual = wsgi.Resource(None, None, None).get_action_args(env)
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_dispatch(self):
         class Controller(object):
@@ -274,7 +274,7 @@ class ResourceTest(test_utils.BaseTestCase):
         resource = wsgi.Resource(None, None, None)
         actual = resource.dispatch(Controller(), 'index', 'on', pants='off')
         expected = ('on', 'off')
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_dispatch_default(self):
         class Controller(object):
@@ -284,7 +284,7 @@ class ResourceTest(test_utils.BaseTestCase):
         resource = wsgi.Resource(None, None, None)
         actual = resource.dispatch(Controller(), 'index', 'on', pants='off')
         expected = ('on', 'off')
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_dispatch_no_default(self):
         class Controller(object):
@@ -315,7 +315,7 @@ class ResourceTest(test_utils.BaseTestCase):
         response = resource.__call__(request)
 
         self.assertIsInstance(response, webob.exc.HTTPForbidden)
-        self.assertEqual(response.status_code, 403)
+        self.assertEqual(403, response.status_code)
 
     @mock.patch.object(wsgi, 'translate_exception')
     def test_resource_call_error_handle_localized(self,
@@ -360,13 +360,13 @@ class JSONResponseSerializerTest(test_utils.BaseTestCase):
         fixture = {"key": "value"}
         expected = '{"key": "value"}'
         actual = wsgi.JSONResponseSerializer().to_json(fixture)
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_to_json_with_date_format_value(self):
-        fixture = {"date": datetime.datetime(1, 3, 8, 2)}
-        expected = '{"date": "0001-03-08T02:00:00"}'
+        fixture = {"date": datetime.datetime(1901, 3, 8, 2)}
+        expected = '{"date": "1901-03-08T02:00:00.000000"}'
         actual = wsgi.JSONResponseSerializer().to_json(fixture)
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_to_json_with_more_deep_format(self):
         fixture = {"is_public": True, "name": [{"name1": "test"}]}
@@ -380,18 +380,18 @@ class JSONResponseSerializerTest(test_utils.BaseTestCase):
         fixture = set(["foo"])
         expected = '["foo"]'
         actual = wsgi.JSONResponseSerializer().to_json(fixture)
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_default(self):
         fixture = {"key": "value"}
         response = webob.Response()
         wsgi.JSONResponseSerializer().default(response, fixture)
-        self.assertEqual(response.status_int, 200)
+        self.assertEqual(200, response.status_int)
         content_types = filter(lambda h: h[0] == 'Content-Type',
                                response.headerlist)
-        self.assertEqual(len(content_types), 1)
-        self.assertEqual(response.content_type, 'application/json')
-        self.assertEqual(response.body, '{"key": "value"}')
+        self.assertEqual(1, len(content_types))
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual('{"key": "value"}', response.body)
 
 
 class JSONRequestDeserializerTest(test_utils.BaseTestCase):
@@ -425,7 +425,7 @@ class JSONRequestDeserializerTest(test_utils.BaseTestCase):
         fixture = '{"key": "value"}'
         expected = {"key": "value"}
         actual = wsgi.JSONRequestDeserializer().from_json(fixture)
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_from_json_malformed(self):
         fixture = 'kjasdklfjsklajf'
@@ -436,7 +436,7 @@ class JSONRequestDeserializerTest(test_utils.BaseTestCase):
         request = wsgi.Request.blank('/')
         actual = wsgi.JSONRequestDeserializer().default(request)
         expected = {}
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_default_with_body(self):
         request = wsgi.Request.blank('/')
@@ -444,15 +444,38 @@ class JSONRequestDeserializerTest(test_utils.BaseTestCase):
         request.body = '{"key": "value"}'
         actual = wsgi.JSONRequestDeserializer().default(request)
         expected = {"body": {"key": "value"}}
-        self.assertEqual(actual, expected)
+        self.assertEqual(expected, actual)
 
     def test_has_body_has_transfer_encoding(self):
+        self.assertTrue(self._check_transfer_encoding(
+                        transfer_encoding='chunked'))
+
+    def test_has_body_multiple_transfer_encoding(self):
+        self.assertTrue(self._check_transfer_encoding(
+                        transfer_encoding='chunked, gzip'))
+
+    def test_has_body_invalid_transfer_encoding(self):
+        self.assertFalse(self._check_transfer_encoding(
+                         transfer_encoding='invalid', content_length=0))
+
+    def test_has_body_invalid_transfer_encoding_with_content_length(self):
+        self.assertTrue(self._check_transfer_encoding(
+                        transfer_encoding='invalid', content_length=5))
+
+    def test_has_body_valid_transfer_encoding_with_content_length(self):
+        self.assertTrue(self._check_transfer_encoding(
+                        transfer_encoding='chunked', content_length=0))
+
+    def _check_transfer_encoding(self, transfer_encoding=None,
+                                 content_length=None):
         request = wsgi.Request.blank('/')
         request.method = 'POST'
         request.body = 'fake_body'
-        request.headers['transfer-encoding'] = 0
-        self.assertIn('transfer-encoding', request.headers)
-        self.assertTrue(wsgi.JSONRequestDeserializer().has_body(request))
+        request.headers['transfer-encoding'] = transfer_encoding
+        if content_length is not None:
+            request.headers['content-length'] = content_length
+
+        return wsgi.JSONRequestDeserializer().has_body(request)
 
     def test_get_bind_addr_default_value(self):
         expected = ('0.0.0.0', '123456')
@@ -466,14 +489,13 @@ class ServerTest(test_utils.BaseTestCase):
         actual = wsgi.Server(threads=1).create_pool()
         self.assertIsInstance(actual, eventlet.greenpool.GreenPool)
 
-    @mock.patch.object(wsgi, 'get_socket')
-    def test_http_keepalive(self, mock_get_socket):
-        fake_socket = 'fake_socket'
-        mock_get_socket.return_value = 'fake_socket'
+    @mock.patch.object(wsgi.Server, 'configure_socket')
+    def test_http_keepalive(self, mock_configure_socket):
         self.config(http_keepalive=False)
         self.config(workers=0)
 
         server = wsgi.Server(threads=1)
+        server.sock = 'fake_socket'
         # mocking eventlet.wsgi server method to check it is called with
         # configured 'http_keepalive' value.
         with mock.patch.object(eventlet.wsgi,
@@ -481,12 +503,13 @@ class ServerTest(test_utils.BaseTestCase):
             fake_application = "fake-application"
             server.start(fake_application, 0)
             server.wait()
-            mock_server.assert_called_once_with(fake_socket,
+            mock_server.assert_called_once_with('fake_socket',
                                                 fake_application,
-                                                log=mock.ANY,
+                                                log=server._wsgi_logger,
                                                 debug=False,
                                                 custom_pool=server.pool,
-                                                keepalive=False)
+                                                keepalive=False,
+                                                socket_timeout=None)
 
 
 class TestHelpers(test_utils.BaseTestCase):
@@ -522,7 +545,7 @@ class TestHelpers(test_utils.BaseTestCase):
                    'properties': {'distro': 'Ubuntu 10.04 LTS'}}
         headers = utils.image_meta_to_http_headers(fixture)
 
-        class FakeResponse():
+        class FakeResponse(object):
             pass
 
         response = FakeResponse()
@@ -559,20 +582,22 @@ class GetSocketTestCase(test_utils.BaseTestCase):
         wsgi.CONF.ca_file = '/etc/ssl/ca_cert'
         wsgi.CONF.tcp_keepidle = 600
 
-    def test_correct_get_socket(self):
+    def test_correct_configure_socket(self):
         mock_socket = mock.Mock()
         self.useFixture(fixtures.MonkeyPatch(
             'glance.common.wsgi.ssl.wrap_socket',
             mock_socket))
         self.useFixture(fixtures.MonkeyPatch(
             'glance.common.wsgi.eventlet.listen',
-            lambda *x, **y: None))
-        wsgi.get_socket(1234)
-        self.assertIn(mock.call().setsockopt(
+            lambda *x, **y: mock_socket))
+        server = wsgi.Server()
+        server.default_port = 1234
+        server.configure_socket()
+        self.assertIn(mock.call.setsockopt(
             socket.SOL_SOCKET,
             socket.SO_REUSEADDR,
             1), mock_socket.mock_calls)
-        self.assertIn(mock.call().setsockopt(
+        self.assertIn(mock.call.setsockopt(
             socket.SOL_SOCKET,
             socket.SO_KEEPALIVE,
             1), mock_socket.mock_calls)
